
RELEASE_VERSION='0.1.516975945'
BUILD_DATE='Thu Apr 14 13:58:37 UTC 2022'
BUILD_MACHINE_INFO='Linux runner-opyxurxq-project-28359933-concurrent-0d2m7x 5.4.181-99.354.amzn2.x86_64 #1 SMP Wed Mar 2 18:50:46 UTC 2022 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='2336706412'
GIT_COMMIT_SHA='96120d4bb3157a8c4023288a4a79d9bf5510aad1'
GIT_BRANCH='main'
